@@ -4,7 +4,7 @@ import os, os.path
 import errno
 import gettext
 
-APP_DATA_DIR    = os.path.join('/usr/local', 'share') 
+APP_DATA_DIR    = os.path.join('/usr', 'share') 
 ICON_DIR        = os.path.join(APP_DATA_DIR, 'pixmaps')
 TEXTURE_DIR     = os.path.join(ICON_DIR, 'glchess')
 GLADE_DIR       = os.path.join(APP_DATA_DIR, 'glchess')
@@ -25,14 +25,14 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.19.6"
+VERSION   = "2.19.90"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
 COPYRIGHT     = _('Copyright 2005-2007 Robert Ancell (and contributors)')
-DESCRIPTION   = _('The 2D/3D chess game for GNOME')
-WEBSITE       = 'http://glchess.sourceforge.net'
-WEBSITE_LABEL = _('glChess homepage')
+DESCRIPTION   = _('The 2D/3D chess game for GNOME. \n\nglChess is a part of GNOME Games.')
+WEBSITE       = 'http://www.gnome.org/projects/gnome-games/'
+WEBSITE_LABEL = _('GNOME Games web site')
 AUTHORS       = ['Robert Ancell <bob27@users.sourceforge.net>']
 ARTISTS       = ['John-Paul Gignac (3D Models)', 'Max Froumentin (2D Models)', 'Hylke Bons <h.bons@student.rug.nl> (icon)']
 
