@@ -2,7 +2,7 @@ import os, os.path
 import errno
 import gettext
 
-APP_DATA_DIR = os.path.join('/usr/local', 'share') 
+APP_DATA_DIR = os.path.join('/usr', 'share') 
 IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
 LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
 GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
@@ -16,12 +16,14 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.19.3"
+VERSION = "2.19.90"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
-DESCRIPTION = _('GNOME Sudoku is a simple sudoku generator and player.  Sudoku is a japanese logic puzzle.')
+DESCRIPTION = _('GNOME Sudoku is a simple sudoku generator and player. Sudoku is a japanese logic puzzle.\n\nGNOME Sudoku is a part of GNOME Games.')
 AUTHORS = ["Thomas M. Hinkle"]
+WEBSITE       = 'http://www.gnome.org/projects/gnome-games/'
+WEBSITE_LABEL = _('GNOME Games web site')
 AUTO_SAVE= True
 MIN_NEW_PUZZLES = 90
 
