@@ -583,7 +583,10 @@ fill_tile_menu (GtkWidget * menu)
       continue;
     }
 
-    gtk_combo_box_append_text (GTK_COMBO_BOX (menu), s);
+    gchar** tileset_name = g_strsplit (s, ".", -1);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (menu), tileset_name[0]);
+    g_strfreev (tileset_name);
+
     tileset_list = g_list_append (tileset_list, s);
     if (!strcmp (tileset, s)) {
       gtk_combo_box_set_active (GTK_COMBO_BOX (menu), itemno);
@@ -934,7 +937,7 @@ about_callback (void)
 #endif
 			 "version", VERSION,
 			 "comments",
-			 _("A matching game played with Mahjongg tiles."),
+			 _("A matching game played with Mahjongg tiles.\n\nMahjongg is a part of GNOME Games."),
 			 "copyright", "Copyright \xc2\xa9 1998-2007 Free Software Foundation, Inc.",
 			 "license", license,
                          "wrap-license", TRUE,
